==> litecoin_0.16.3.orig.tar.xz: litecoin-0.16.3/src/qt/locale/bitcoin_ur_PK.ts <==
<TS language="ur_PK" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>پتہ تبدیل کرے کے لیے دائیاں کلک کریں</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>نیا ایڈریس بنائیں</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>نیا</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>سلیکٹڈ پتے کو کمپوٹر کی عارضی جگہ رکھیں</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>نقل</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>بند</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>سلیکٹڈ پتے کو مٹائیں</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>موجودہ ڈیٹا کو فائیل میں محفوظ کریں</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>برآمد</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>مٹا</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>کوئین وصول کرنے والے کا پتہ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>کوئین وصول کرنے والے کا پتہ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>چننا</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>پاس فریز داخل کریں</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>نیا پاس فریز</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>نیا پاس فریز دہرائیں</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>رقم:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>کاپی پتہ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>رقم:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>بیلنس:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
</context>
</TS>

==> litecoin_0.18.1.orig.tar.xz: litecoin-0.18.1/src/qt/locale/bitcoin_ur_PK.ts <==
<TS language="ur_PK" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>پتہ تبدیل کرے کے لیے دائیاں کلک کریں</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>نیا ایڈریس بنائیں</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>نیا</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>سلیکٹڈ پتے کو کمپوٹر کی عارضی جگہ رکھیں</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>نقل</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>بند</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>سلیکٹڈ پتے کو مٹائیں</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>موجودہ ڈیٹا کو فائیل میں محفوظ کریں</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>برآمد</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>مٹا</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>کوئین وصول کرنے والے کا پتہ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>کوئین وصول کرنے والے کا پتہ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>چننا</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>پتے ارسال کیے جارہے ہیں</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>پتے موصول ہورہے ہیں</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;پتا نقل کریں</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>&amp;لیبل نقل کریں</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;تدوین</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>پتا فہرست ایکسپورٹ کریں</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>کاما سے جدا فائلیں (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ایکسپورٹ ناکام ہوا</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>لیبل</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>پاس فریز داخل کریں</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>نیا پاس فریز</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>نیا پاس فریز دہرائیں</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>رقم:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>چٹ</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation> پتہ</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>رقم</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>کاپی پتہ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>لیبل</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>لیبل</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>رقم:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>بیلنس:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>لیبل</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>کاما سے جدا فائلیں (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>لیبل</translation>
    </message>
    <message>
        <source>Address</source>
        <translation> پتہ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ایکسپورٹ ناکام ہوا</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>ناکافی فنڈز</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>نقص</translation>
    </message>
</context>
</TS>
